16.111. cdist-type__package_pkg(7) — cdist 6.9.8 documentation

# 16.111. cdist-type__package_pkg(7)

## 16.111.1. NAME

cdist-type__package_pkg - Manage OpenBSD packages

## 16.111.2. DESCRIPTION

This type is usually used on OpenBSD to manage packages.

## 16.111.3. REQUIRED PARAMETERS

None

## 16.111.4. OPTIONAL PARAMETERS

name

  If supplied, use the name and not the object id as the package name.

flavor

  If supplied, use to avoid ambiguity.

version

  If supplied, use to avoid ambiguity.

state

  Either "present" or "absent", defaults to "present"

pkg_path

  Manually specify a PKG_PATH to add packages from.

## 16.111.5. EXAMPLES

    # Ensure zsh is installed
    __package_pkg_openbsd zsh --state present

    # Ensure vim is installed, use flavor no_x11
    __package_pkg_openbsd vim --state present --flavor no_x11

    # If you don't want to follow pythonX packages, but always use python
    __package_pkg_openbsd python --state present --name python2

    # Remove obsolete package
    __package_pkg_openbsd puppet --state absent

    # Add a package using a particular mirror
    __package_pkg_openbsd bash \
      --pkg_path http://openbsd.mirrorcatalogs.com/snapshots/packages/amd64

## 16.111.6. SEE ALSO

cdist-type__package(7)

## 16.111.7. AUTHORS

Andi Brönnimann <andi-cdist--@--v-net.ch>

## 16.111.8. COPYING

Copyright (C) 2011 Andi Brönnimann. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).